@@ -46,8 +46,8 @@ static void pixbuf_document_document_thumbnails_iface_init (EvDocumentThumbnails
 
 EV_BACKEND_REGISTER_WITH_CODE (PixbufDocument, pixbuf_document,
                    {
-			 G_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_THUMBNAILS,
-						pixbuf_document_document_thumbnails_iface_init)				   
+			 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_THUMBNAILS,
+							 pixbuf_document_document_thumbnails_iface_init)				   
 		   });
 
 static gboolean
